@@ -2,15 +2,15 @@
 #define STRICT_R_HEADERS
 #include <Rcpp.h>
 
+#if __cplusplus >= 201703L
 #include "simdjson.h"
 #include "simdjson.cpp"
-
-using namespace simdjson;
+#endif
 
 // [[Rcpp::export(.validateJSON)]]
 bool validateJSON(const std::string filename) {
 #if __cplusplus >= 201703L
-  simdjson::padded_string p = get_corpus(filename.c_str());
+  simdjson::padded_string p = simdjson::get_corpus(filename.c_str());
   simdjson::ParsedJson pj = simdjson::build_parsed_json(p); // do the parsing
   if ( !pj.is_valid() ) {
     // something went wrong
@@ -27,3 +27,8 @@ bool validateJSON(const std::string filename) {
 int cppVersion() {
   return __cplusplus;
 }
+
+// [[Rcpp::export(.unsupportedArchitecture)]]
+bool unsupportedArchitecture() {
+  return (simdjson::active_implementation->name() == "unsupported");
+}
